/* MODEL NUMBER:
   MODEL NAME:
   SHORT DESCRIPTION:
*/
import nsrunit; unit conversion on;
//
/*
  2 compartment model for 2 species, A and B, both tracher (h) and
  non-tracer (c), with flow and competitive transporter
*/
math Comp2_hc_AB_Trans {
//% INDEPENDENT VARIABLE
realDomain t s; t.min=0; t.max=30; t.delta = 0.1;
// PARAMETERS
real Fp	= 1 ml/(g*min);		// Flow 
real Ga2b	= 1 ml/(g*min); // Conversion rate of A to B
real Vp = 0.05 ml/g;		// Volume of V%n%
real Vc = 0.60 ml/g;		// Volume of V%n%
real Surf	= 1 cm^2/g;
real SoVp	= Surf/Vp;
real SoVc	= Surf/Vc;
real KdhAp	= 1 uM;
real KdhAc	= 1 uM;
real KdhBp	= 1 uM;
real KdhBc	= 1 uM;
real KdcAp	= 1 uM;
real KdcAc	= 1 uM;
real KdcBp	= 1 uM;
real KdcBc	= 1 uM;
real konhAp	= 10 uM^(-1)*s^(-1);
real konhAc	= 10 uM^(-1)*s^(-1);
real konhBp	= 10 uM^(-1)*s^(-1);
real konhBc	= 10 uM^(-1)*s^(-1);
real koncAp	= 10 uM^(-1)*s^(-1);
real koncAc	= 10 uM^(-1)*s^(-1);
real koncBp	= 10 uM^(-1)*s^(-1);
real koncBc	= 10 uM^(-1)*s^(-1);
real kofhAp	= konhAp*KdhAp;
real kofhAc	= konhAc*KdhAc;
real kofhBp	= konhBp*KdhBp;
real kofhBc	= konhBc*KdhBc;
real kofcAp	= koncAp*KdcAp;
real kofcAc	= koncAc*KdcAc;
real kofcBp	= koncBp*KdcBp;
real kofcBc	= koncBc*KdcBc;
real Ttot	= 0.2 umol/cm^2;
real kTp2c	= 10 sec^(-1);
real kTc2p	= 10 sec^(-1);
real kThAp2c	= 10 sec^(-1);
real kThAc2p	= 10 sec^(-1);
real kThBp2c	= 10 sec^(-1);
real kThBc2p	= 10 sec^(-1);
real kTcAp2c	= 10 sec^(-1);
real kTcAc2p	= 10 sec^(-1);
real kTcBp2c	= 10 sec^(-1);
real kTcBc2p	= 10 sec^(-1);
extern real hAin(t) mM;		// Inflow Conc
extern real hBin(t) mM;		// Inflow Conc
extern real cAin(t) mM;		// Inflow Conc
extern real cBin(t) mM;		// Inflow Conc
// DEPENDENT VARIABLES
real hAp(t) mM;		// Conc 
real hAc(t) mM;		// Conc 
real hBp(t) mM;		// Conc 
real hBc(t) mM;		// Conc 
real cAp(t) mM;		// Conc 
real cAc(t) mM;		// Conc 
real cBp(t) mM;		// Conc 
real cBc(t) mM;		// Conc 
real hAout(t) mM;		// Outflow Conc
real hBout(t) mM;		// Outflow Conc
real cAout(t) mM;		// Outflow Conc
real cBout(t) mM;		// Outflow Conc
real hApic = 0 mM;	// Init Conc 
real hAcic = 0 mM;	// Init Conc 
real hBpic = 0 mM;	// Init Conc 
real hBcic = 0 mM;	// Init Conc 
real cApic = 0 mM;	// Init Conc 
real cAcic = 0 mM;	// Init Conc 
real cBpic = 0 mM;	// Init Conc 
real cBcic = 0 mM;	// Init Conc 
real Tp(t) umol/cm^2;
real Tc(t) umol/cm^2;
real ThAp(t) umol/cm^2;
real ThAc(t) umol/cm^2;
real ThBp(t) umol/cm^2;
real ThBc(t) umol/cm^2;
real TcAp(t) umol/cm^2;
real TcAc(t) umol/cm^2;
real TcBp(t) umol/cm^2;
real TcBc(t) umol/cm^2;
real ThApic = 0 umol/cm^2;
real ThAcic = 0 umol/cm^2;
real ThBpic = 0 umol/cm^2;
real ThBcic = 0 umol/cm^2;
real TcApic = 0 umol/cm^2;
real TcAcic = 0 umol/cm^2;
real TcBpic = 0 umol/cm^2;
real TcBcic = 0 umol/cm^2;
// INITIAL CONDITIONS
when(t=t.min) hAp=hApic;
when(t=t.min) hAc=hAcic;
when(t=t.min) hBp=hBpic;
when(t=t.min) hBc=hBcic;
when(t=t.min) cAp=cApic;
when(t=t.min) cAc=cAcic;
when(t=t.min) cBp=cBpic;
when(t=t.min) cBc=cBcic;
when(t=t.min) ThAp=ThApic;
when(t=t.min) ThAc=ThAcic;
when(t=t.min) ThBp=ThBpic;
when(t=t.min) ThBc=ThBcic;
when(t=t.min) TcAp=TcApic;
when(t=t.min) TcAc=TcAcic;
when(t=t.min) TcBp=TcBpic;
when(t=t.min) TcBc=TcBcic;
when(t=t.min) Tp = Ttot/2;
when(t=t.min) Tc = Ttot/2;
// ORDINARY DIFFERENTIAL EQUATIONS
hAp:t = (Fp/Vp)*(hAin-hAout)
      +(-konhAp*hAp*Tp + kofhAp*ThAp)*SoVp;
hAout = hAp;
hBp:t = (Fp/Vp)*(hBin-hBout)
      +(-konhBp*hBp*Tp + kofhBp*ThBp)*SoVp;
hBout = hBp;
cAp:t = (Fp/Vp)*(cAin-cAout)
      +(-koncAp*cAp*Tp + kofcAp*TcAp)*SoVp;
cAout = cAp;
cBp:t = (Fp/Vp)*(cBin-cBout)
      +(-koncBp*cBp*Tp + kofcBp*TcBp)*SoVp;
cBout = cBp;
Tp:t = -konhAp*hAp*Tp + kofhAp*ThAp 
     -konhBp*hBp*Tp + kofhBp*ThBp 
     -koncAp*cAp*Tp + kofcAp*TcAp 
     -koncBp*cBp*Tp + kofcBp*TcBp 
     - kTp2c*Tp + kTc2p*Tc;
ThAp:t = konhAp*hAp*Tp - kofhAp*ThAp
       - kThAp2c*ThAp + kThAc2p*ThAc;
hAc:t = (-konhAc*hAc*Tc + kofhAc*ThAc)*SoVc
      -Ga2b/Vc*hAc;
Tc:t = -konhAc*hAc*Tc + kofhAc*ThAc 
     -konhBc*hBc*Tc + kofhBc*ThBc 
     -koncAc*cAc*Tc + kofcAc*TcAc 
     -koncBc*cBc*Tc + kofcBc*TcBc 
     +kTp2c*Tp - kTc2p*Tc;
ThAc:t = konhAc*hAc*Tc - kofhAc*ThAc
       +kThAp2c*ThAp - kThAc2p*ThAc;
ThBp:t = konhBp*hBp*Tp - kofhBp*ThBp
       - kThBp2c*ThBp + kThBc2p*ThBc;
hBc:t = (-konhBc*hBc*Tc + kofhBc*ThBc)*SoVc
      +Ga2b/Vc*hAc;
ThBc:t = konhBc*hBc*Tc - kofhBc*ThBc
       +kThBp2c*ThBp - kThBc2p*ThBc;
TcAp:t = koncAp*cAp*Tp - kofcAp*TcAp
       - kTcAp2c*TcAp + kTcAc2p*TcAc;
cAc:t = (-koncAc*cAc*Tc + kofcAc*TcAc)*SoVc
      -Ga2b/Vc*cAc;
TcAc:t = koncAc*cAc*Tc - kofcAc*TcAc
       +kTcAp2c*TcAp - kTcAc2p*TcAc;
TcBp:t = koncBp*cBp*Tp - kofcBp*TcBp
       - kTcBp2c*TcBp + kTcBc2p*TcBc;
cBc:t = (-koncBc*cBc*Tc + kofcBc*TcBc)*SoVc
      +Ga2b/Vc*cAc;
TcBc:t = koncBc*cBc*Tc - kofcBc*TcBc
       +kTcBp2c*TcBp - kTcBc2p*TcBc;
}
/*
DETAILED DESCRIPTION:
//
KEY WORDS:
//
REFERENCES:
// 
REVISION HISTORY:
//
JSim SOFTWARE COPYRIGHT AND REQUEST FOR ACKNOWLEDGMENT OF USE:
   
JSim software was developed with support from NIH grants HL088516, 
and HL073598. Please cite these grants in any publication for which 
this software is used and send one reprint of published abstracts or 
articles to the address given below. Academic use is unrestricted. 
Software may be copied so long as this copyright notice is included.
Copyright (C) 1999-2011 University of Washington.
Contact Information:
 
The National Simulation Resource,  
Director J. B. Bassingthwaighte, 
Department of Bioengineering, 
University of Washington, Seattle, WA 
98195-5061
*/
// This MML file generated from ../COMP2/Comp2_hc_AB_Trans.mpc using MPC.
