//%START bartaJavaCode
/* REFERENCE
 * Barta E, Sideman S, and Bassingthwaighte JB. Facilitated diffusion and
 * membrane permeation of fatty acid in  albumin solutions. Ann Biomed Eng 28:
 * 331-345, 2000.
*/
source procedure BARTA(Atot, Ftot, Kd; A0, F0, AF0) {
/*  
     Solve Atot = A0+AF0
           Ftot = F0+AF0
           A0*F0/AF0 = Kd    for A0, F0, AF0 assuming all parameters
                             are in the same units.  */
	language="java";
	reentrant="true";
	maincode={{
	    double CFt = Ftot.realVal();
	    double CAt = Atot.realVal();
	    double Kd1 = Kd.realVal();
	    double solpa = (0.5)*(CFt+CAt+Kd1);
	    double solpb = (0.5)*(Math.sqrt( Math.pow(CFt-CAt-Kd1,2)+4*CFt*Kd1)
);  
            double solp1 = solpa+solpb;
	    double solp2 = solpa-solpb;
	    double CAF1  = solp1;
	    double CAF2  = solp2;
	    double CF1   = CFt-solp1;
	    double CF2   = CFt-solp2;
	    double CA1   = CAt-solp1;
	    double CA2   = CAt-solp2;
            if( CAF1>0 && CF1>0 &&  CA1>0) {
	        A0.set(CA1);
                F0.set(CF1);
                AF0.set(CAF1);
	    } else {
	        A0.set(CA2);
	        F0.set(CF2);
	        AF0.set(CAF2);
            }
	}};
}  
//%END bartaJavaCode
import nsrunit; unit conversion on;
math Barta {
realDomain t sec; t.min=0; t.max=10; t.delta=0.01;
//%START bartaInit 
real kd uM, Atot uM, Ftot uM;
real a uM,   f uM,    af uM;
real Kd = 30 nM;		// Equilibrium dissociation constant
real CAt = 1.5e-9 mole/ml;	// Total Albumin
real CFt = 1.0e-10 mole/ml;	// Total Fatty Acid
kd =Kd;				// Convert to mM
Atot=CAt;			// Convert to mM
Ftot=CFt;			// Convert to mM
BARTA(Atot, Ftot, kd, a, f, af);

real A(t) uM, F(t) uM, AF(t) uM;
real km1 = 0.142 s^(-1);        // Dissoc rate constant for AF
real kp1 = km1/kd;              // Assoc rate constant for A+F
when(t=t.min) {A=a; F=f; AF=af;}
//%END bartaInit

//%START bartaCalc
A:t = -kp1*A*F + km1*AF;
F:t = -kp1*A*F + km1*AF;
AF:t = kp1*A*F - km1*AF;
//%END bartaCalc

} // END
