math CodeLibrary {
real version = 1.0; 
}
/*--------------- CONSTRUCT MODULAR PROGRAM CONSTRUCTOR LIBRARY
//------------------------------ ODE DOMAINS
//%START odeDomains
//% INDEPENDENT VARIABLE
realDomain t s; t.min=0; t.max=30; t.delta = 0.1;
//%END odeDomains

//------------------------------ PDE DOMAINS
//%START pdeDomains
// INDEPENDENT VARIABLES
realDomain  t s; t.min=0; t.max=30; t.delta = 0.1;
real L = 0.1 cm;
real Ndivx = 31;
realDomain x cm ; x.min=0; x.max=L; x.ct = Ndivx;
//%END pdeDomains
//------------------------------ BOUNDARY CONDITIONS
//%START flowBC
when  (x=x.min) (-F*L/V)*(C-Cin)+D*C:x = 0; 
when  (x=x.max) { C:x = 0; Cout = C;}
//%END flowBC
//%START noFlowBC
when(x=x.min)  C:x=0;
when(x=x.max)  C:x=0; 
//%END noFlowBC
//------------------------------ ODE FLOW CALCULATION
//%START flowODECalc
C:t = (F/V)*(Cin-Cout);
Cout = C;
//%END flowODECalc
//------------------------------ FLOW DIFF CALCULATION
//%START           flowDiffCalc
C:t =  -(F*L/V)*C:x
       + D*C:x:x ;
//%END             flowDiffCalc
//------------------------------ DIFFUSION CALCULATION
//%START diffusionCalc
C:t = D*C:x:x ;
//%END diffusionCalc
//------------------------------ EXCHANGE CACULATIONS
//%START exchangeCalc
C1:t	= PS/V1*(C2-C1);
C2:t	= PS/V2*(C1-C2);
//%END exchangeCalc
//
//------------------------------ CONSUME CALCULATION
//%START consumeCalc
C:t = -(G/V)*C;
//%END consumeCalc
//
//------------------------------ REACTION A->B
//%START reactionCalc1
A:t = -G/V*A;
B:t = G/V*A;
//%END reactionCalc1
//
//----------------------------- MMREACTION A->B
//%START mmReactionCalc
GA = GmaxA/(KmA+A);
A:t = -GA*A/V;
B:t = +GA*A/V;
//%END mmReactionCalc
//
//------------------------------ ENZYME CALCULATION
//%START enzymeCalc
A:t = -kf1*A*Enzyme + kb1*Complex;
B:t =  kf2*Complex - kb2*B*Enzyme;
Enzyme:t = -(kf1*A + kb2*B)*Enzyme 
           + (kb1 + kf2)*Complex;
Complex:t = (kf1*A + kb2*B)*Enzyme 
           - (kb1 + kf2)*Complex;
//%END enzymeCalc
//------------------------------ ENZYME ADDITIONAL PARAMETERS
//%START enzymeParms
real Complex(t) mM;
real Enzyme(t) mM;
real Etot = 0.1 mM;
real kf1 = 2 mM^(-1)*s^(-1);
real kb1 = 1 s^(-1);
real kf2 = 1 s^(-1);
real kb2 = 1 mM^(-1)*s^(-1);
when(t=t.min) { Complex=0; Enzyme=Etot; }         
//%END enzymeParms
//------------------------------ EXTRACTION CALCULATION
//%START extractionCalc
real extract(t);
extract=if(href>0 and href>hperm) 1-hperm/href else 0;
realState Emax(t);
when(t=t.min) Emax=0;
event(t>t.min and Emax<extract) Emax=extract;
real PSmax = -F*ln(1.0-Emax(t.max));
//
//%END extractionCalc 
//------------------------------ TRANSPORTER CALCULATION
//%START transporterCalc
A1:t  =  koffA1*TA1*SoV1 - konA1*A1*T1*SoV1;
A2:t  =  koffA2*TA2*SoV2 - konA2*A2*T2*SoV2;
T1:t  = -konA1*A1*T1 + koffA1*TA1 -COEFF* (kT12*T1   - kT21*T2) ;
T2:t  = -konA2*A2*T2 + koffA2*TA2 +COEFF* (kT12*T1   - kT21*T2) ;
TA1:t =  konA1*A1*T1 - koffA1*TA1 - kTA12*TA1 + kTA21*TA2;
TA2:t =  konA2*A2*T2 - koffA2*TA2 + kTA12*TA1 - kTA21*TA2;
//%END transporterCalc
//------------------------------ TRANSPORTER ADDITIONAL PARAMETERS
//%START transporterParms
real KdA1	= 10 uM;	//Eqlbrm dissoc constant on side 1
real KdA2	= 10 uM;	//Eqlbrm dissoc constant on side 2
real konA1	= 1 uM^(-1)*s^(-1);	//Binding rate side 1 for A1 
real konA2	= 1 uM^(-1)*s^(-1);	//Binding rate side 2 for A2
real koffA1	= KdA1*konA1;	//Dissoc rate s^(-1) side 1 for TA1
real koffA2	= KdA2*konA2;	//Dissoc rate s^(-1) side 2 for TA2
real kTA12	= 100 s^(-1);	//TA flip rate side 1-> side 2
real kTA21	= 100 s^(-1);	//TA flip rate side 2-> side 1
real kT12	= 100 s^(-1);	   //T flip rate side 1-> side 2
real kT21	= 100 s^(-1);	   //T flip rate side 2 -> side 1
real Surf	= 1 cm^2;	//Surface area for exchange
real Ttot	= 0.1 umol/cm^2;	//Total Transp conc
real SoV1	cm^(-1);	// Surf to vol ratio 
real SoV2	cm^(-1);	// Surf to vol ratio
real T1(t)	umol/(cm^2);	// Free transporter on side 1
real T2(t)	umol/(cm^2);	// Free transporter on side 2
SoV1  = Surf/V1;
SoV2  = Surf/V2;  
when(t=t.min) {T1=0.5*Ttot; T2 = 0.5*Ttot;}
//%END transporterParms
//------------------------------ STANDARD DOCUMENTATION
//%START standardInitialize
/* MODEL NUMBER:
   MODEL NAME:
   SHORT DESCRIPTION:
*/
import nsrunit; unit conversion on;
//
//%END   standardInitialize
//%START standardClosing
/*
DETAILED DESCRIPTION:
//
KEY WORDS:
//
REFERENCES:
// 
REVISION HISTORY:
//
JSim SOFTWARE COPYRIGHT AND REQUEST FOR ACKNOWLEDGMENT OF USE:
   
JSim software was developed with support from NIH grants HL088516, 
and HL073598. Please cite these grants in any publication for which 
this software is used and send one reprint of published abstracts or 
articles to the address given below. Academic use is unrestricted. 
Software may be copied so long as this copyright notice is included.
Copyright (C) 1999-2011 University of Washington.
Contact Information:
 
The National Simulation Resource,  
Director J. B. Bassingthwaighte, 
Department of Bioengineering, 
University of Washington, Seattle, WA 
98195-5061
*/
//%END   standardClosing
//------------------------------ BARTA JAVA CODE
//%START bartaJavaCode
/* REFERENCE
 * Barta E, Sideman S, and Bassingthwaighte JB. Facilitated diffusion and
 * membrane permeation of fatty acid in  albumin solutions. Ann Biomed Eng 28:
 * 331-345, 2000.
*/
source procedure BARTA(Atot, Ftot, Kd; A0, F0, AF0) {
/*  
     Solve Atot = A0+AF0
           Ftot = F0+AF0
           A0*F0/AF0 = Kd    for A0, F0, AF0 assuming all parameters
                             are in the same units.  */
	language="java";
	reentrant="true";
	maincode={{
	    double CFt = Ftot.realVal();
	    double CAt = Atot.realVal();
	    double Kd1 = Kd.realVal();
	    double solpa = (0.5)*(CFt+CAt+Kd1);
	    double solpb = (0.5)*(Math.sqrt( Math.pow(CFt-CAt-Kd1,2)+4*CFt*Kd1)
);  
            double solp1 = solpa+solpb;
	    double solp2 = solpa-solpb;
	    double CAF1  = solp1;
	    double CAF2  = solp2;
	    double CF1   = CFt-solp1;
	    double CF2   = CFt-solp2;
	    double CA1   = CAt-solp1;
	    double CA2   = CAt-solp2;
            if( CAF1>0 && CF1>0 &&  CA1>0) {
	        A0.set(CA1);
                F0.set(CF1);
                AF0.set(CAF1);
	    } else {
	        A0.set(CA2);
	        F0.set(CF2);
	        AF0.set(CAF2);
            }
	}};
}  
//%END bartaJavaCode
  
//------------------------------ BARTA CALC
//%START bartaCalc
A:t = -kp1*A*F + km1*AF;
F:t = -kp1*A*F + km1*AF;
AF:t = kp1*A*F - km1*AF;
//%END bartaCalc
//------------------------------ ON OFF MEMBRANE BINDING SITE
//%START           onOffMembraneCalc
M:t = (-kon*M*B + kof*MB)*SoV;
B:t =  -kon*M*B + kof*MB ;
MB:t =  kon*M*B - kof*MB;
//%END             onOffMembraneCalc
//------------------------------ CONFORMATIONAL CHANGE (FLIP)
//%START                  flipa2bCalc
a:t = - ka2b*a + kb2a*b;
b:t =   ka2b*a - kb2a*b;
//%END                    flipa2bCalc
//------------------------------ OUTFLOW CURVE STATS (JAVA)
//%START curveStatJava
//*****************************************************************************
/* Statistics on a curve */
source procedure curveStatistics(input@t,output@t; ai,ti,RDi,ao,tao,RDo,tsys,RDsys) {
/* ai  (ao)       area of input (output) curve
   ti  (to)       transit time of input (output) curve
   RDi (RDo)      relative dispersion of input (output) curve
   tsys           transit time of the system
   RDsys          relative dispersion of the system
   NOTA BENE, the results are not dimensionally scaled or checked.
   A basic assumption is that both the input and output have the
   same units.  
   Corrects the calculation by 1/2*t.delta in the output signal. */
       language="java";
       maincode={{
           RegularGridData t = (RegularGridData) input.grid(0);
           double S1=0; double S2=0; double S3=0;
           double T1=0; double T2=0; double T3=0;
           for (int i=0; i<t.ct(); i++) {
               double time = t.min()+((double)i)*t.delta();
               double time2 = time*time;
               double timeO=time-t.delta()/2;
               double timeO2=timeO*timeO;
               double in=input.realVal(i);
               double ot=output.realVal(i);
               S1+=in;
               S2+=in*time;
               S3+=in*time2;
               T1+=ot;
               T2+=ot*timeO;
               T3+=ot*timeO2;
           }
           ai.set(t.delta()*S1);
           double tI=S2/S1;
           ti.set(tI);
           double rdI=( Math.sqrt((Math.abs(S3/S2)/(S2/S1))-1));
           RDi.set(rdI);
           ao.set(t.delta()*T1);
           double tO=T2/T1;
           tao.set(tO);
           double rdO=( Math.sqrt((Math.abs(T3/T2)/(T2/T1))-1));
           RDo.set(rdO);
           tsys.set(tO-tI);
           RDsys.set( Math.sqrt(rdO*tO*rdO*tO-rdI*tI*rdI*tI)/(tO-tI) );
         }};
} // END
//%END curveStatJava
//----------------------------- CURVE STATS CALCULATION (MML)
//%START transitCalc
/*
   ai  ( ao)          area of input (output) curve
   ti  ( to,  tsys)   transit time of input (output, system)
   RDi (RDo, RDsys)   relative dispersion of input (output, system) 
*/
real ai, ti,RDi,ao,tao,RDo,tsys,RDsys;
curveStatistics(Cin@t,Cout@t,ai,ti,RDi,ao,tao,RDo,tsys,RDsys);
//%END transitCalc
//----------------------------- MULTIFLOWS
//%START multiFlowCalc()
//
/* NOTA BENE!************************************
   To use this code in a MultiFlow model, you
   must remove the real declaration for flow in
   the model (e.g. remove real Fp = 1 ml/(g*min);
   from a BTEX10 when making MultiFlowBTEX10.
*/
   private real NPATH   = PATHS*1;
   public real NPATHS   = NPATH;
   real relFmin = 0.05 ;
   real relFmax = 3.0 ;
//
   realDomain NP ; NP.min=1; NP.max=NPATH; NP.delta=1;
   private NP.min, NP.max, NP.delta, NP.ct;
//
   realDomain NPp1 ; NPp1.min=1; NPp1.max=NPATH+1; NPp1.delta=1;
   private NPp1.min, NPp1.max, NPp1.delta, NPp1.ct;
//
   realDomain rflo ; rflo.min=relFmin; rflo.max=relFmax; rflo.delta=0.01;
   private rflo.min, rflo.max,  rflo.delta, rflo.ct;
//
   extern real relFpdf(rflo) ;	// pdf for relative flows
   private real cumpdf(rflo) ;
   when(rflo=rflo.min) cumpdf=0;
   cumpdf:rflo=relFpdf;
   choice SPACING ("= in log(relative flow)","= in transit time","= in relative flow") = 1;
   private real spacing = SPACING;
//
// SPACE FLOW BINS EVENLY IN SPACING DOMAIN
   private real srelFmin , srelFmax , swidth ;
   srelFmin = if(spacing=1) ln(relFmin) else
                if(spacing=2) 1/relFmin   else
                relFmin;
   srelFmax = if(spacing=1) ln(relFmax) else
                if(spacing=2) 1/relFmax   else
                relFmax;
   swidth = (srelFmax-srelFmin)/NPATH;
//
// COMPUTE ENDS OF EACH RELATIVE FLOW BIN
   private real ends(NPp1) ;         // ends of each flow bin
   ends(NPp1) = if(spacing=1) exp(srelFmin+(NPp1-1)*swidth) else
             if(spacing=2) 1/ (srelFmin+(NPp1-1)*swidth) else
                           (srelFmin+(NPp1-1)*swidth);
//
// MAKE EACH RELATIVE FLOW THE CENTER OF ITS FLOW BIN
   real f(NP) ;       // relative flows
   f(NP) = (ends(NP+1)+ends(NP))/2;
//
// INTERPOLATE cumpdf(rflo) TO GET cumValues(NPp1);
   private real cumValues(NPp1) ;    // cumpdf(rflo)->cumValues(PATHS+1)
   cumValues(NPp1) = cumpdf(ends(NPp1));
//
// GENERATE WT FOR EACH BIN so that integral wt*df=1
   private real wt(NP) ;             // d(cumValues)/d(ends)
   wt(NP)=(cumValues(NP+1)-cumValues(NP))/(ends(NP+1)-ends(NP));
   real wdsum ;              // for normalization
   wdsum = sum( (wt)@NP);
//
// NORMALIZE WEIGHTS
   real wts(NP) ;            // normalized weights
   wts(NP) = wt(NP)/wdsum;
// FINISH ALGORITHM FOR HETEROGENEOUS FLOW
//
//%END multiFlowCalc()
//----------------------------- VASCULAR OPERATOR 4th ORDER
//%START vascOpCalc
// 
// ************************ VASCULAR OPERATOR FOR Cin->Cout **********
// 
 private /* fixed parameters */
 real RD4th = 0.47884124 dimensionless, // 4th order operator
      zeta1 = 0.95 dimensionless,    // 1st 2nd order op damping
      zeta2 = 0.80 dimensionless,    // 2nd 2nd order op damping
      wratio = 1.82 dimensionless;   // wratio = w_2 / w_1
 when (t=t.min) {C1=Cic; dC1dt=Cic/(1 s); C2=Cic; dC2dt=Cic/(1 s); }
 rd         = if (RD<0) 0 else if (RD>RD4th) RD4th else RD;
 totalDelay = V/F;
 op4Delay   = (rd/RD4th)*totalDelay;             
 pureDelay  = totalDelay-op4Delay;    
 w1         = if (op4Delay>0) (2/op4Delay)*(zeta1+zeta2/wratio) else 0;
 w2         = w1*wratio;
 Cdelay = if(t<=t.min+pureDelay) Cic  
          else Cin(t-t.min-pureDelay);       
 C1:t = dC1dt;
 dC1dt:t = -2*zeta1*w1*dC1dt +w1^2*(Cdelay-C1);  
 C2:t = dC2dt;
 dC2dt:t = -2*zeta2*w2*dC2dt + w2^2*(C1-C2);    
 Cout = if (op4Delay>0) C2 else Cdelay;
//%END vascOpCalc
*/
// This MML file generated from ../CODELIB/CodeLibrary.mpc using MPC.
