import nsrunit; unit conversion on;

math Transporter{ 
real COEFF = 1;
// INDEPENDENT VARIABLE
realDomain t sec; t.min = 0; t.max = 30; t.delta = 0.1;
//PARAMETERS AND VARIABLES
real A1(t) mM;		// Conc of A1 in V1
real A2(t) mM;		// Conc of A2 in V2
real A10 = 1 mM;	// Init conc of A1
real A20 = 0 mM;	// Init conc of A2
real V1  = 1 ml;	// Volume of V1
real V2  = 1 ml;	// Volume of V2
real TA1(t) umol/cm^2;	// Transporter complex with A1
real TA2(t) umol/cm^2;	// Transporter complex with A2
	 when(t=t.min) {A1 = A10; A2=A20; TA1 = 0; TA2 = 0; }
//%START transporterParms
real KdA1	= 10 uM;	//Eqlbrm dissoc constant on side 1
real KdA2	= 10 uM;	//Eqlbrm dissoc constant on side 2
real konA1	= 1 uM^(-1)*s^(-1);	//Binding rate side 1 for A1 
real konA2	= 1 uM^(-1)*s^(-1);	//Binding rate side 2 for A2
real koffA1	= KdA1*konA1;	//Dissoc rate s^(-1) side 1 for TA1
real koffA2	= KdA2*konA2;	//Dissoc rate s^(-1) side 2 for TA2
real kTA12	= 100 s^(-1);	//TA flip rate side 1-> side 2
real kTA21	= 100 s^(-1);	//TA flip rate side 2-> side 1
real kT12	= 100 s^(-1);	   //T flip rate side 1-> side 2
real kT21	= 100 s^(-1);	   //T flip rate side 2 -> side 1
real Surf	= 1 cm^2;	//Surface area for exchange
real Ttot	= 0.1 umol/cm^2;	//Total Transp conc
real SoV1	cm^(-1);	// Surf to vol ratio 
real SoV2	cm^(-1);	// Surf to vol ratio
real T1(t)	umol/(cm^2);	// Free transporter on side 1
real T2(t)	umol/(cm^2);	// Free transporter on side 2
SoV1  = Surf/V1;
SoV2  = Surf/V2;  
when(t=t.min) {T1=0.5*Ttot; T2 = 0.5*Ttot;}
//%END transporterParms

// ODEs
//%START transporterCalc 
A1:t  =  koffA1*TA1*SoV1 - konA1*A1*T1*SoV1;
A2:t  =  koffA2*TA2*SoV2 - konA2*A2*T2*SoV2;
T1:t  = -konA1*A1*T1 + koffA1*TA1 -COEFF* (kT12*T1   - kT21*T2) ;
T2:t  = -konA2*A2*T2 + koffA2*TA2 +COEFF* (kT12*T1   - kT21*T2) ;
TA1:t =  konA1*A1*T1 - koffA1*TA1 - kTA12*TA1 + kTA21*TA2;
TA2:t =  konA2*A2*T2 - koffA2*TA2 + kTA12*TA1 - kTA21*TA2;
//%END transporterCalc
}
