 import nsrunit; unit conversion on;
 math VascularOperator {
 // INDEPENDENT VARIABLE
 realDomain t sec; t.min=0; t.max=10; t.delta=0.1;
 // PARAMETERS
 real F = 1 ml/(g*min),
      V = 0.02 ml/g,
      RD = 0.2 dimensionless;
 extern real Cin(t) mM;
 real Cic = 0 mM, Cout(t) mM;           // Init Conc, Outflow Conc
 private
 real rd dimensionless,            // Enforces 0<=RD<=RD4th
      totalDelay sec,              // total transit time
      pureDelay sec,               // the pure delay  transit time
      op4Delay sec,                // 4th order operator transit time
      w1 sec^(-1),                 // 1st 2nd order op frequency
      w2 sec^(-1),                 // 2nd 2nd order op frequency
      Cdelay(t) mM,                // output of pure delay operator
      C1(t) mM, dC1dt(t) mM/sec,   // 1st 2nd op variables
      C2(t) mM, dC2dt(t) mM/sec;   // 2nd 2nd op variables
 // ********************* CALCULATION FOR Cout 4th ORDER DELAY OPERATOR
//%START vascOpCalc
// 
// ************************ VASCULAR OPERATOR FOR Cin->Cout **********
// 
 private /* fixed parameters */
 real RD4th = 0.47884124 dimensionless, // 4th order operator
      zeta1 = 0.95 dimensionless,    // 1st 2nd order op damping
      zeta2 = 0.80 dimensionless,    // 2nd 2nd order op damping
      wratio = 1.82 dimensionless;   // wratio = w_2 / w_1

 when (t=t.min) {C1=Cic; dC1dt=Cic/(1 s); C2=Cic; dC2dt=Cic/(1 s); }
 rd         = if (RD<0) 0 else if (RD>RD4th) RD4th else RD;
 totalDelay = V/F;
 op4Delay   = (rd/RD4th)*totalDelay;             
 pureDelay  = totalDelay-op4Delay;    
 w1         = if (op4Delay>0) (2/op4Delay)*(zeta1+zeta2/wratio) else 0;
 w2         = w1*wratio;
 Cdelay = if(t<=t.min+pureDelay) Cic  
          else Cin(t-t.min-pureDelay);       
 C1:t = dC1dt;
 dC1dt:t = -2*zeta1*w1*dC1dt +w1^2*(Cdelay-C1);  
 C2:t = dC2dt;
 dC2dt:t = -2*zeta2*w2*dC2dt + w2^2*(C1-C2);    
 Cout = if (op4Delay>0) C2 else Cdelay;
//%END vascOpCalc
 }



 
