/* MODEL NUMBER:
   MODEL NAME:
   SHORT DESCRIPTION:
*/
import nsrunit; unit conversion on;
//
/*
  2 compartment model for two species, A and B, with flow 
  and membrane transporter. p is plasma, c is cell.
*/
math Comp2_AB_Trans {
//% INDEPENDENT VARIABLE
realDomain t s; t.min=0; t.max=30; t.delta = 0.1;
// PARAMETERS
real Fp		= 1 ml/(g*min);		// Flow 
real Ga2b	= 1 ml/(g*min); // Conversion rate of A to B
real Vp 	= 0.05 ml/g;		// Volume of V%n%
real Vc 	= 0.60 ml/g;		// Volume of V%n%
real Surf	= 1 cm^2/g;
real SoVp	= Surf/Vp;
real SoVc	= Surf/Vc;
real KdAp	= 1 uM;
real KdAc	= 1 uM;
real KdBp	= 1 uM;
real KdBc	= 1 uM;
real konAp	= 10 uM^(-1)*s^(-1);
real konAc	= 10 uM^(-1)*s^(-1);
real konBp	= 10 uM^(-1)*s^(-1);
real konBc	= 10 uM^(-1)*s^(-1);
real kofAp	= konAp*KdAp;
real kofAc	= konAc*KdAc;
real kofBp	= konBp*KdBp;
real kofBc	= konBc*KdBc;
real Ttot	= 0.2 umol/cm^2;
real kTp2c	= 10 sec^(-1);
real kTc2p	= 10 sec^(-1);
real kTAp2c	= 10 sec^(-1);
real kTAc2p	= 10 sec^(-1);
real kTBp2c	= 10 sec^(-1);
real kTBc2p	= 10 sec^(-1);
extern real Ain(t) mM;		// Inflow Conc
extern real Bin(t) mM;		// Inflow Conc
// DEPENDENT VARIABLES
real Ap(t) mM;		// Conc 
real Ac(t) mM;		// Conc 
real Bp(t) mM;		// Conc 
real Bc(t) mM;		// Conc 
real Aout(t) mM;		// Outflow Conc
real Bout(t) mM;		// Outflow Conc
private real Apic = 0 mM;	// Init Conc 
private real Acic = 0 mM;	// Init Conc 
private real Bpic = 0 mM;	// Init Conc 
private real Bcic = 0 mM;	// Init Conc 
real Tp(t) umol/cm^2;
real Tc(t) umol/cm^2;
real TAp(t) umol/cm^2;
real TAc(t) umol/cm^2;
real TBp(t) umol/cm^2;
real TBc(t) umol/cm^2;
real TApic = 0 umol/cm^2;
real TAcic = 0 umol/cm^2;
real TBpic = 0 umol/cm^2;
real TBcic = 0 umol/cm^2;
// INITIAL CONDITIONS
when(t=t.min) Ap=Apic;
when(t=t.min) Ac=Acic;
when(t=t.min) Bp=Bpic;
when(t=t.min) Bc=Bcic;
when(t=t.min) TAp=TApic;
when(t=t.min) TAc=TAcic;
when(t=t.min) TBp=TBpic;
when(t=t.min) TBc=TBcic;
when(t=t.min) Tp = Ttot/2;
when(t=t.min) Tc = Ttot/2;
// ORDINARY DIFFERENTIAL EQUATIONS
Ap:t = (Fp/Vp)*(Ain-Aout)
     +(-konAp*Ap*Tp + kofAp*TAp)*SoVp;
Aout = Ap;
Bp:t = (Fp/Vp)*(Bin-Bout)
     +(-konBp*Bp*Tp + kofBp*TBp)*SoVp;
Bout = Bp;
Tp:t = -konAp*Ap*Tp + kofAp*TAp 
     -konBp*Bp*Tp + kofBp*TBp 
     - kTp2c*Tp + kTc2p*Tc;
TAp:t = konAp*Ap*Tp - kofAp*TAp
      - kTAp2c*TAp + kTAc2p*TAc;
Ac:t = (-konAc*Ac*Tc + kofAc*TAc)*SoVc
     -Ga2b/Vc*Ac;
Tc:t = -konAc*Ac*Tc + kofAc*TAc 
     -konBc*Bc*Tc + kofBc*TBc 
     +kTp2c*Tp - kTc2p*Tc;
TAc:t = konAc*Ac*Tc - kofAc*TAc
      +kTAp2c*TAp - kTAc2p*TAc;
TBp:t = konBp*Bp*Tp - kofBp*TBp
      - kTBp2c*TBp + kTBc2p*TBc;
Bc:t = (-konBc*Bc*Tc + kofBc*TBc)*SoVc
     +Ga2b/Vc*Ac;
TBc:t = konBc*Bc*Tc - kofBc*TBc
      +kTBp2c*TBp - kTBc2p*TBc;
}
/*
DETAILED DESCRIPTION:
//
KEY WORDS:
//
REFERENCES:
// 
REVISION HISTORY:
//
JSim SOFTWARE COPYRIGHT AND REQUEST FOR ACKNOWLEDGMENT OF USE:
   
JSim software was developed with support from NIH grants HL088516, 
and HL073598. Please cite these grants in any publication for which 
this software is used and send one reprint of published abstracts or 
articles to the address given below. Academic use is unrestricted. 
Software may be copied so long as this copyright notice is included.
Copyright (C) 1999-2011 University of Washington.
Contact Information:
 
The National Simulation Resource,  
Director J. B. Bassingthwaighte, 
Department of Bioengineering, 
University of Washington, Seattle, WA 
98195-5061
*/
// This MML file generated from ../COMP2/Comp2_AB_Trans.mpc using MPC.
