/* MODEL NUMBER:
   MODEL NAME:
   SHORT DESCRIPTION:
*/
import nsrunit; unit conversion on;
//
/*
   2 compartment model with flow and transporter on membrane
   p is plasma, c is cell
*/
math Comp2_A_Trans {
//% INDEPENDENT VARIABLE
realDomain t s; t.min=0; t.max=30; t.delta = 0.1;
// PARAMETERS
real Fp 	= 1 ml/(g*min);	// Flow 
real Gp 	= 1 ml/(g*min);	// Consumption rate
real Gc 	= 1 ml/(g*min);	// Consumption rate
real Vp 	= 0.05 ml/g;	// Volume 
real Vc 	= 0.60 ml/g;	// Volume 
real Surf	= 1 cm^2/g;	// Surface area of membrane
real SoVp	= Surf/Vp;	// Surface to volume ratio
real SoVc	= Surf/Vc;	// Surface to volume ratio
real KdAp	= 1 uM;		// Dissociation constant
real KdAc	= 1 uM;		// Dissociation constant
real konAp	= 10 uM^(-1)*s^(-1);	// On rate
real konAc	= 10 uM^(-1)*s^(-1);	// On rate
real kofAp	= konAp*KdAp;	// Off rate
real kofAc	= konAc*KdAc;	// Off rate
real Ttot	= 0.2 umol/cm^2;	// Total transporters
real kTp2c	= 10 sec^(-1);		// Flip rate free transporter
real kTc2p	= 10 sec^(-1);		// Flip rate free transporter
real kTAp2c	= 10 sec^(-1);		// Flip rate bound transporter
real kTAc2p	= 10 sec^(-1);		// Flip rate bound transporter
extern real Ain(t) mM;		// Inflow Conc
// DEPENDENT VARIABLES
real Ap(t) mM;		// Conc 
real Ac(t) mM;		// Conc 
real Aout(t) mM;		// Outflow Conc
private real Apic = 0 mM;	// Init Conc 
private real Acic = 0 mM;	// Init Conc 
real Tp(t) umol/cm^2;
real Tc(t) umol/cm^2;
real TAp(t) umol/cm^2;
real TAc(t) umol/cm^2;
real TApic	= 0 umol/cm^2;	// Init Conc Bound transporter
real TAcic	= 0 umol/cm^2;	// Init Conc Bound transporter
// INITIAL CONDITIONS
when(t=t.min) Ap=Apic;
when(t=t.min) Ac=Acic;
when(t=t.min) TAp=TApic;
when(t=t.min) TAc=TAcic;
when(t=t.min) Tp = Ttot/2;
when(t=t.min) Tc = Ttot/2;
// ORDINARY DIFFERENTIAL EQUATIONS
Ap:t = (Fp/Vp)*(Ain-Aout)
     -(Gp/Vp)*Ap
     +(-konAp*Ap*Tp + kofAp*TAp)*SoVp;
Aout = Ap;
Ac:t = -(Gc/Vc)*Ac
     +(-konAc*Ac*Tc + kofAc*TAc)*SoVc;
Tp:t = -konAp*Ap*Tp + kofAp*TAp 
     - kTp2c*Tp + kTc2p*Tc;
TAp:t = konAp*Ap*Tp - kofAp*TAp
      - kTAp2c*TAp + kTAc2p*TAc;
Tc:t = -konAc*Ac*Tc + kofAc*TAc 
     +kTp2c*Tp - kTc2p*Tc;
TAc:t = konAc*Ac*Tc - kofAc*TAc
      +kTAp2c*TAp - kTAc2p*TAc;
}
/*
DETAILED DESCRIPTION:
//
KEY WORDS:
//
REFERENCES:
// 
REVISION HISTORY:
//
JSim SOFTWARE COPYRIGHT AND REQUEST FOR ACKNOWLEDGMENT OF USE:
   
JSim software was developed with support from NIH grants HL088516, 
and HL073598. Please cite these grants in any publication for which 
this software is used and send one reprint of published abstracts or 
articles to the address given below. Academic use is unrestricted. 
Software may be copied so long as this copyright notice is included.
Copyright (C) 1999-2011 University of Washington.
Contact Information:
 
The National Simulation Resource,  
Director J. B. Bassingthwaighte, 
Department of Bioengineering, 
University of Washington, Seattle, WA 
98195-5061
*/
// This MML file generated from ../COMP2/Comp2_A_Trans.mpc using MPC.
